@@ -130,8 +130,8 @@ proc htmlize-text {text {charmap {}}} {
 	\"	{&quot;} \
 	{<}	{&lt;} \
 	{>}	{&gt;} \
-	\u201c "&ldquo;" \
-	\u201d "&rdquo;"
+	\u201C "&ldquo;" \
+	\u201D "&rdquo;"
 
     return [string map $charmap $text]
 }
@@ -1303,8 +1303,8 @@ proc make-manpage-section {outputDir sectionDescriptor} {
     global manual overall_title tcltkdesc verbose
     global excluded_pages forced_index_pages process_first_patterns
 
-    set LQ \u201c
-    set RQ \u201d
+    set LQ \u201C
+    set RQ \u201D
 
     lassign $sectionDescriptor \
 	manual(wing-glob) \
@@ -1314,6 +1314,7 @@ proc make-manpage-section {outputDir sectionDescriptor} {
     set manual(wing-copyrights) {}
     makedirhier $outputDir/$manual(wing-file)
     set manual(wing-toc-fp) [open $outputDir/$manual(wing-file)/[indexfile] w]
+    fconfigure $manual(wing-toc-fp) -translation lf -encoding utf-8
     # whistle
     puts stderr "scanning section $manual(wing-name)"
     # put the entry for this section into the short table of contents
@@ -1364,6 +1365,7 @@ proc make-manpage-section {outputDir sectionDescriptor} {
 	    continue
 	}
 	set manual(infp) [open $manual(page)]
+	fconfigure $manual(infp) -encoding utf-8
 	set manual(text) {}
 	set manual(partial-text) {}
 	foreach p {.RS .DS .CS .SO} {
