@@ -11,8 +11,8 @@
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
+#undef STATIC_BUILD
 #include "tcl.h"
-
 
 /*
  *----------------------------------------------------------------------
@@ -31,15 +31,15 @@
  *----------------------------------------------------------------------
  */
 
-int
+DLLEXPORT int
 Pkge_Init(
     Tcl_Interp *interp)		/* Interpreter in which the package is to be
 				 * made available. */
 {
-    static char script[] = "if 44 {open non_existent}";
+    static const char script[] = "if 44 {open non_existent}";
 
-    if (Tcl_InitStubs(interp, TCL_VERSION, 0) == NULL) {
+    if (Tcl_InitStubs(interp, "8.5", 0) == NULL) {
 	return TCL_ERROR;
     }
-    return Tcl_Eval(interp, script);
+    return Tcl_EvalEx(interp, script, -1, 0);
 }
